# PAPI Basic logging functions
# Copyright (c) 2001-2005, RedIRIS. All Rights Reserved.
#
# You may distribute under the terms of the GNU General Public License,
# as specified in the LICENSE file that was shipped with this distribution.
#
# These functions implement simple PAPI user authentication logging
#

package PAPI::BasicLog;
use strict;
use Sys::Syslog qw/:DEFAULT setlogsock/;

# This function is intended to be hooked at the logHook in a
# PAPI AuthServer. It uses the configuration variables 'syslogFacility'
# ("local7" by default) and  'syslogPriority' ("info" by default) to send
# the information to the syslog program.
# It logs the outcome of the authentication process and the username
# submitted (read from the connection variables 'host', 'username',
# `PAPIerror' and `PAPIop').
#
sub Syslog {
   my $res = shift;
   my $con = shift;
   my $cfg = shift;

   my $fac = "local7";
   $fac = $$cfg{'syslogFacility'} if (exists $$cfg{'syslogFacility'});
   my $prio = "info";
   $prio = $$cfg{'syslogPriority'} if (exists $$cfg{'syslogPriority'});
   
   setlogsock 'unix';
   openlog ("PAPI\:\:AuthServer", "pid", $fac);
   if ($res eq "accept") {
      syslog ($prio, "Host: %s. User: %s. Operation %s accepted. Userid: %s",
              $$con{'host'}, $$con{'username'},
              $$con{'PAPIop'}, $$con{'PAPIuid'});
   }
   elsif ($res eq "reject") {
      syslog ($prio, "Host: %s. User: %s. Operation %s rejected. Cause: %s",
              $$con{'host'}, $$con{'username'},
              $$con{'PAPIop'}, $$con{'PAPIerror'});
   }
   else {
      syslog ($prio, "Host: %s. %s. Userid: %s", $$con{'host'},
              $res, $$con{'PAPIuid'});
   }
   closelog ();
}

# This function is intended to be hooked at the logHook in a
# PAPI AuthServer. It uses the configuration variables 'logFile'
# ($configuration{'workingDirectory'}/log by default) to store the
# log information into a file.
# It logs the outcome of the authentication process and the username
# submitted (read from the connection variables 'host', 'username',
# `PAPIerror' and `PAPIop').
#
sub FileLog {
   my $res = shift;
   my $con = shift;
   my $cfg = shift;

   my $thef = "$$cfg{workingDirectory}/log";
   $thef = $$cfg{'logFile'} if (exists $$cfg{'logFile'});
   my ($se, $mi, $ho, $md, $mn, $yn) = localtime (time);
   my $mo = ("Jan","Feb","Mar","Apr","May","Jun",
             "Jul","Aug","Sep","Oct","Nov","Dec")[$mn];
   my $ye = 1900 + $yn;

   open (LOGFILE, ">> $thef") or return;
   printf LOGFILE "%d %s %2d %2.2d:%2.2d:%2.2d PAPI::AuthServer[%s]: ", 
          $ye, $mo, $md, $ho, $mi, $se, $$;
   if ($res eq "accept") {
      print LOGFILE "Host: $$con{host}. User: $$con{username}. Operation $$con{PAPIop} accepted. ";
      print LOGFILE "Userid: $$con{PAPIuid}\n";
   }
   elsif ($res eq "reject") {
      print LOGFILE "Host: $$con{host}. User: $$con{username}. Operation $$con{PAPIop} rejected. ";
      print LOGFILE "Cause: $$con{PAPIerror}\n";
   }
   else {
      print LOGFILE "Host: $$con{host}. $res. Userid: $$con{PAPIuid}\n";
   }
   close (LOGFILE);
}

1;
